@@ -75,7 +75,7 @@ class XmippProtCreateMask3D(ProtCreateMask3D, XmippGeometricalMask3D):
         # For volume sources
         isVolume = 'source==%d' % SOURCE_VOLUME
         form.addParam('inputVolume', PointerParam, pointerClass="Volume",
-                      label="Input volume",  condition=isVolume,
+                      label="Input volume", allowsNull=True, condition=isVolume,
                       help="Select the volume that will be used to create the mask")
         form.addParam('volumeOperation', EnumParam, default=OPERATION_THRESHOLD,
                       choices=['Threshold', 'Segment', 'Only postprocess'],
