@@ -52,6 +52,8 @@ from xmipp3.protocols import XmippProtMovieGain
 from xmipp3.protocols import XmippProtDeepDenoising
 from xmipp3.protocols import XmippProtParticleBoxsize
 from .plotter import XmippPlotter
+from xmipp3.protocols import XmippProtTiltAnalysis
+from pwem.viewers.viewers_data import MicrographsView
 
 
 class XmippViewer(DataViewer):
@@ -77,7 +79,8 @@ class XmippViewer(DataViewer):
                 XmippProtAngularGraphConsistency,
                 XmippProtMovieGain,
                 XmippProtDeepDenoising,
-                XmippProtParticleBoxsize
+                XmippProtParticleBoxsize,
+                XmippProtTiltAnalysis
                 ]
 
     def __createTemporaryCtfs(self, obj, setOfMics):
@@ -126,6 +129,9 @@ class XmippViewer(DataViewer):
         #                                   viewParams={OBJCMDS: objCommands},
         #                                   **kwargs))
 
+
+
+
         elif (issubclass(cls, XmippProtExtractParticles) or
               issubclass(cls, XmippProtScreenParticles)):
             particles = obj.outputParticles
@@ -198,6 +204,38 @@ class XmippViewer(DataViewer):
                                                            'labels': '_size',
                                                            'sortby': 'id'})
 
+        elif issubclass(cls, XmippProtTiltAnalysis):
+            if obj.hasAttribute('discardedMicrographs'):
+                fn = obj.discardedMicrographs.getFileName()
+                labels = ('id enabled psdCorr._filename _filename _tilt_mean_corr _tilt_std_corr '
+                          '_tilt_max_corr _tilt_min_corr _tilt_psds_image._filename ')
+                labelRender = (' psdCorr._filename _tilt_psds_image._filename')
+
+                self._views.append(ObjectView(self._project, obj.strId(), fn,
+                                              viewParams={ORDER: labels,
+                                                          VISIBLE: labels,
+                                                          RENDER: labelRender,
+                                                          ZOOM: 25,
+                                                          MODE: MODE_MD}))
+
+            if obj.hasAttribute('outputMicrographs'):
+                fn = obj.outputMicrographs.getFileName()
+                labels = ('id enabled psdCorr._filename _filename _tilt_mean_corr _tilt_std_corr '
+                          '_tilt_max_corr _tilt_min_corr _tilt_psds_image._filename ')
+                labelRender = (' psdCorr._filename _tilt_psds_image._filename')
+
+                self._views.append(ObjectView(self._project, obj.strId(), fn,
+                                                   viewParams={ORDER: labels,
+                                                   VISIBLE: labels,
+                                                   RENDER: labelRender,
+                                                   ZOOM: 25,
+                                                   MODE: MODE_MD}))
+
+            if not(obj.hasAttribute('discardedMicrographs')) and not(obj.hasAttribute('outputMicrographs')):
+                self._views.append(self.infoMessage("Output micrographs has "
+                                                    "not been produced yet."))
+
+
         elif issubclass(cls, XmippProtCompareReprojections):
                 fn = obj.reprojections.getFileName()
                 labels = ('id enabled _index _xmipp_image._filename _xmipp_imageRef._filename '
