@@ -40,6 +40,7 @@ from pyworkflow.protocol.constants import LEVEL_ADVANCED
 from pyworkflow.protocol.params import (LabelParam, IntParam, FloatParam,
                                         StringParam, EnumParam,
                                         NumericRangeParam, BooleanParam)
+import pyworkflow.utils as pwutils
 from xmipp3.convert import *
 from xmipp3.viewers.plotter import XmippPlotter
 from xmipp3.protocols import XmippProtProjMatch
@@ -221,7 +222,7 @@ Examples:
         if self.showRef3DNo == REF_ALL:
             self._refsList = range(1, self.protocol.numberOfReferences+1)
         else:
-            self._refsList = self._getListFromRangeString(self.ref3DSelection.get())
+            self._refsList = pwutils.getListFromRangeString(self.ref3DSelection.get())
         # ToDo: enhance this
         self.firstIter = 1
         #self.lastIter = self.protocol.numberOfIterations.get()
@@ -230,7 +231,7 @@ Examples:
         if self.viewIter.get() == ITER_LAST:
             self._iterations = [self.lastIter]
         else:
-            self._iterations = self._getListFromRangeString(self.iterSelection.get())
+            self._iterations = pwutils.getListFromRangeString(self.iterSelection.get())
             
         from matplotlib.ticker import FuncFormatter
         self._plotFormatter = FuncFormatter(self._formatFreq) 
